@@ -29,7 +29,6 @@
  * Copyright (c) 1986-1991 by Sun Microsystems Inc. 
  */
 
-#include <sys/cdefs.h>
 
 /*
  * rpc_generic.c, Miscl routines for RPC.
@@ -228,16 +227,16 @@ __rpc_getconfip(nettype)
 	extern thread_key_t tcp_key, udp_key;
 	extern mutex_t tsd_lock;
 
-	if (tcp_key == -1) {
+	if (tcp_key == KEY_INITIALIZER) {
 		mutex_lock(&tsd_lock);
-		if (tcp_key == -1)
+		if (tcp_key == KEY_INITIALIZER)
 			thr_keycreate(&tcp_key, free);
 		mutex_unlock(&tsd_lock);
 	}
 	netid_tcp = (char *)thr_getspecific(tcp_key);
-	if (udp_key == -1) {
+	if (udp_key == KEY_INITIALIZER) {
 		mutex_lock(&tsd_lock);
-		if (udp_key == -1)
+		if (udp_key == KEY_INITIALIZER)
 			thr_keycreate(&udp_key, free);
 		mutex_unlock(&tsd_lock);
 	}
@@ -535,7 +534,9 @@ __rpc_nconf2fd_flags(const struct netconfig *nconf, int flags)
 	    si.si_af == AF_INET6) {
 		int val = 1;
 
+#ifdef INET6
 		setsockopt(fd, SOL_IPV6, IPV6_V6ONLY, &val, sizeof(val));
+#endif
 	}
 	return fd;
 }
@@ -606,6 +607,7 @@ __rpc_taddr2uaddr_af(int af, const struct netbuf *nbuf)
 	struct sockaddr_in6 *sin6;
 	char namebuf6[INET6_ADDRSTRLEN];
 #endif
+	int path_len;
 	u_int16_t port;
 
 	if (nbuf->len <= 0)
@@ -636,13 +638,12 @@ __rpc_taddr2uaddr_af(int af, const struct netbuf *nbuf)
 #endif
 	case AF_LOCAL:
 		sun = nbuf->buf;
-		/*	if (asprintf(&ret, "%.*s", (int)(sun->sun_len -
-		    offsetof(struct sockaddr_un, sun_path)),
-		    sun->sun_path) < 0)*/
-		if (asprintf(&ret, "%.*s", (int)(sizeof(*sun) -
-						 offsetof(struct sockaddr_un, sun_path)),
-			     sun->sun_path) < 0)
 
+		path_len = nbuf->len - offsetof(struct sockaddr_un, sun_path);
+		if (path_len < 0)
+			return NULL;
+
+		if (asprintf(&ret, "%.*s", path_len, sun->sun_path) < 0)
 			return (NULL);
 		break;
 	default:
